@@ -63,6 +63,7 @@ import sys
 import os
 import time
 import ctypes
+import thread
 try:
     from queue import Queue     #@UnresolvedImport @UnusedImport (python3)
 except ImportError:
@@ -137,10 +138,10 @@ class XpraClient(XpraClientBase, gobject.GObject):
         self.server_display = None
         self.server_randr = False
         self.server_auto_refresh_delay = 0
-        self.pixel_counter = maxdeque(maxlen=100)
-        self.server_ping_latency = maxdeque(maxlen=100)
+        self.pixel_counter = maxdeque(maxlen=200)
+        self.server_ping_latency = maxdeque(maxlen=200)
         self.server_load = None
-        self.client_ping_latency = maxdeque(maxlen=100)
+        self.client_ping_latency = maxdeque(maxlen=200)
         self._server_ok = True
         self.last_ping_echoed_time = 0
         self.server_info_request = False
@@ -239,10 +240,6 @@ class XpraClient(XpraClientBase, gobject.GObject):
         if (self.max_bandwidth):
             self.last_input_bytecount = 0
             gobject.timeout_add(2000, compute_receive_bandwidth, 2000)
-        if opts.pings:
-            gobject.timeout_add(1000, self.send_ping)
-        else:
-            gobject.timeout_add(10*1000, self.send_ping)
 
     def init_mmap(self, mmap_group, socket_filename):
         log("init_mmap(%s, %s)", mmap_group, socket_filename)
@@ -381,13 +378,13 @@ class XpraClient(XpraClientBase, gobject.GObject):
 
     def cleanup(self):
         log("XpraClient.cleanup() client_extras=%s", self._client_extras)
+        XpraClientBase.cleanup(self)
         if self._client_extras:
             self._client_extras.cleanup()
-        if self.sound_sink:
-            self.stop_receiving_sound()
         if self.sound_source:
-            self.stop_sending_sound()
-        XpraClientBase.cleanup(self)
+            thread.start_new_thread(self.stop_sending_sound, ())
+        if self.sound_sink:
+            thread.start_new_thread(self.stop_receiving_sound, ())
         self.clean_mmap()
         #the protocol has been closed, it is now safe to close all the windows:
         #(cleaner and needed when we run embedded in the client launcher)
@@ -1107,11 +1104,21 @@ class XpraClient(XpraClientBase, gobject.GObject):
         self.send("encoding", encoding)
 
     def _screen_size_changed(self, *args):
-        root_w, root_h = get_root_size()
-        log.debug("sending updated screen size to server: %sx%s", root_w, root_h)
-        self.send("desktop_size", root_w, root_h, self.get_screen_sizes())
-        #update the max packet size (may have gone up):
-        self.set_max_packet_size()
+        def update_size(current=None):
+            root_w, root_h = self.get_root_size()
+            ss = self.get_screen_sizes()
+            log("update_size(%s) sizes=%s", current, ss)
+            if current is not None and current==ss:
+                #unchanged
+                return
+            log.info("sending updated screen size to server: %sx%s, screen sizes: %s", root_w, root_h, ss)
+            self.send("desktop_size", root_w, root_h, ss)
+            #update the max packet size (may have gone up):
+            self.set_max_packet_size()
+            #check again soon:
+            gobject.timeout_add(1000, update_size, ss)
+        #update via idle_add so the data is actually up to date when we query it!
+        self.idle_add(update_size)
 
     def get_screen_sizes(self):
         screen_sizes = []
