@@ -350,6 +350,8 @@ class XpraServer(gobject.GObject, X11ServerBase):
                 #if window is set, we failed after instantiating it,
                 #so we need to fail it manually:
                 window.setup_failed(e)
+                if window in self._window_to_id:
+                    self._lost_window(window, False)
             else:
                 log.warn("cannot add %s: %s", hex(xid), e)
             #from now on, we return to the gtk main loop,
@@ -610,7 +612,7 @@ class XpraServer(gobject.GObject, X11ServerBase):
         width = maxx-minx
         height = maxy-miny
         log("screenshot: %sx%s, min x=%s y=%s", width, height, minx, miny)
-        import Image
+        from PIL import Image
         image = Image.new("RGBA", (width, height))
         for wid, x, y, w, h, pixmap in reversed(all_regions):
             _, _, wid, _, _, w, h, _, raw_data, rowstride, _, _ = get_rgb_rawdata(0, 0, wid, pixmap, 0, 0, w, h, "rgb24", -1, None, logger=log.debug)
